eml.resources package
=====================

Resources
---------

Representation of resource objects in the Ecological Metadata Language.

Resource Type
~~~~~~~~~~~~~

.. automodule:: eml.resources.resources
   :members:
   :undoc-members:
   :show-inheritance:

Resource Base Class
~~~~~~~~~~~~~~~~~~~

.. automodule:: eml.resources.resource
   :members:
   :undoc-members:
   :show-inheritance:

Citation Resource
~~~~~~~~~~~~~~~~~

.. automodule:: eml.resources.citation
   :members:
   :undoc-members:
   :show-inheritance:

Dataset Resource
~~~~~~~~~~~~~~~~

.. automodule:: eml.resources.dataset
   :members:
   :undoc-members:
   :show-inheritance:

Protocol Resource
~~~~~~~~~~~~~~~~~

.. automodule:: eml.resources.protocol
   :members:
   :undoc-members:
   :show-inheritance:

Software Resource
~~~~~~~~~~~~~~~~~

.. automodule:: eml.resources.software
   :members:
   :undoc-members:
   :show-inheritance:

Resource Group
--------------

Representation of resource group objects that are defined as children of a Resource object.

KeywordSet Class
~~~~~~~~~~~~~~~~

.. automodule:: eml.resources.keyword_set
   :members:
   :undoc-members:
   :show-inheritance:

License Class
~~~~~~~~~~~~~

.. automodule:: eml.resources.licence
   :members:
   :undoc-members:
   :show-inheritance:

Distribution Class
~~~~~~~~~~~~~~~~~~

.. automodule:: eml.resources.distribution.distribution
   :members:
   :undoc-members:
   :show-inheritance:

Distribution accessory classes
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. toctree::
   :maxdepth: 4

   eml.resources.distribution

Coverage Class
~~~~~~~~~~~~~~

.. automodule:: eml.resources.coverage.coverage
   :members:
   :undoc-members:
   :show-inheritance:

Coverage accessory classes
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. toctree::
   :maxdepth: 4

   eml.resources.coverage
